@@ -1,5 +1,6 @@
 package Module::Build::Scintilla::OSX;
 
+use 5.006;
 use strict;
 use warnings;
 use Module::Build::Scintilla;
@@ -35,7 +36,7 @@ sub stc_scintilla_dll {
 	$dllname .= 'd' if Alien::wxWidgets->config->{debug};
 	$dllname .= '_scintilla-';
 	my ( $major, $minor, $release ) = $self->stc_version_strings;
-	$dllname .= $major . '.' . $minor . '.dylib';
+	$dllname .= $major . '.' . $minor . '.' . $release . '.dylib';
 	return $dllname;
 }
 
@@ -91,6 +92,9 @@ sub stc_link_scintilla_objects {
 sub stc_build_xs {
 	my ($self) = @_;
 
+	# Do not build XS if it is up to date
+	return if $self->up_to_date( 'Scintilla.c', 'Scintilla.o' );
+
 	my $dist_version = $self->dist_version;
 
 	# we must remove any nostdinc params
